# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
✨ Added `readout_type` and `readout_platform` | [1](https://github.com/laminlabs/bioreader/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-27 | 0.0.2
